VPSPulse Mirrors

High-Performance Open-Source Archive

Help for package iccde

Package {iccde}


Type: Package
Title: Computation of the Double-Entry Intraclass Correlation
Version: 0.3.9
Description: The functions compute the double-entry intraclass correlation, which is an index of profile similarity (Furr, 2010; McCrae, 2008). The double-entry intraclass correlation is a more precise index of the agreement of two empirically observed profiles than the often-used intraclass correlation (McCrae, 2008). Profiles comprising correlations are automatically transformed according to the Fisher z-transformation before the double-entry intraclass correlation is calculated. If the profiles comprise scores such as sum scores from various personality scales, it is recommended to standardize each individual score prior to computation of the double-entry intraclass correlation (McCrae, 2008). See Furr (2010) <doi:10.1080/00223890903379134> or McCrae (2008) <doi:10.1080/00223890701845104> for details.
License: GPL-2 | GPL-3 [expanded from: GPL (≥ 2)]
Encoding: UTF-8
NeedsCompilation: no
Packaged: 2026-06-12 18:06:04 UTC; christianblotner
Author: Christian Blötner [aut, cre], Michael Paul Grosz [aut]
Maintainer: Christian Blötner <c.bloetner@gmail.com>
Repository: CRAN
Date/Publication: 2026-06-12 18:30:02 UTC

Bootstrap Confidence Intervals for Double-Entry Intraclass Correlations)

Description

For different applications, confidence intervals for the double- entry intraclass correlation can be useful. Bootstrap confidence intervals are computed by means of repeated resampling from the original data at hand.

Usage

icc.de.boot(data,
            n.sim = 1000,
            alpha = .05,
            use = "pairwise",
            digit = 3)

Arguments

data

A data frame with participants in rows and variables in columns. Users should restrict the data set to the variables of concrete interest because the all available information in the data frame will be used to compute bootstrapped confidence intervals. Thus, it is advisable to create a new data frame that entails only the variables on which the matrix of ICCDEs should be based.

n.sim

The number of iterations to be carried out. Default is 1,000.

alpha

Type I error. Default is .05.

use

Optional character string specifying how to deal with missing values. The input will be forwarded to the base cor function and can be one of the following strings, including abbreviation: "everything", "all.obs", "complete.obs", "na.or.complete", or "pairwise.complete.obs". The default is use = "pairwise".

digit

Number of digits in the output. Default is 3.

Value

The output provides a list with the following elements.

M

A matrix of the bootstrapped point estimates of the bootstrapped double-entry intraclass correlations.

LL

A matrix providing the lower limits of the bootstrap confidence intervals, given the desired alpha level.

UL

A matrix providing the upper limits of the bootstrap confidence intervals, given the selected alpha level.

Mean

A vector of the mean correlation per row of the raw correlation matrix (i.e., not bootstrapped), excluding the diagonal element.

SD

A vector of the standard deviations of the correlations per row of the raw correlation matrix (i.e., not bootstrapped), excluding the diagonal element.

Author(s)

Christian Blötner, Michael Paul Grosz c.bloetner@gmail.com

References

Furr, R. M. (2010). The Double-Entry Intraclass Correlation as an index of profile similarity: Meaning, limitations, and alternatives. Journal of Personality Assessment, 92(1), 1–15. <https://doi.org/10.1080/00223890903379134>

McCrae, R. R. (2008). A note on some measures of profile agreement. Journal of Personality Assessment, 90(2), 105–109. <https://doi.org/10.1080/00223890701845104>

Examples

df <- data.frame(a = rnorm(100), b = rnorm(100), c = rnorm(100),
                 x = rnorm(100), y = rnorm(100), z = rnorm(100))
icc.de.boot(data = df,
            n.sim = 10, # just for illustration. Use higher n.sim in real data
            alpha = .01,
            digit = 2)

Computation of Double-Entry Intraclass Correlations for correlation matrices

Description

This function computes pairwise double-entry intraclass correlations among all entries of a data frame. Correlations between the compared variables as well as correlations of the constructs with themselves are thereby excluded from the calculation (i.e., correlations between X and Y, correlation between X and X, and correlation between Y and Y).

Usage

icc.de.mat(data, use = "pairwise", digit)

Arguments

data

A data frame with participants in rows and variables in columns.

use

Optional character string specifying how to deal with missing values. The input will be forwarded to the base cor function and can be one of the following strings, including abbreviation: "everything", "all.obs", "complete.obs", "na.or.complete", or "pairwise.complete.obs". The default is use = "pairwise".

digit

Number of digits in the output. The default is 3.

Value

The output contains a list with the following elements.

iccde

A matrix of double-entry intraclass correlations among the entered variables.

Mean

A vector of the mean correlation per row of the correlation matrix, excluding the diagonal element.

SD

A vector of the standard deviations of the correlations per row of the correlation matrix, excluding the diagonal element.

Author(s)

Christian Blötner, Michael Paul Grosz c.bloetner@gmail.com

References

Furr, R. M. (2010). The Double-Entry Intraclass Correlation as an Index of Profile Similarity: Meaning, Limitations, and Alternatives. Journal of Personality Assessment, 92(1), 1–15. https://doi.org/10.1080/00223890903379134

McCrae, R. R. (2008). A Note on Some Measures of Profile Agreement. Journal of Personality Assessment, 90(2), 105–109. https://doi.org/10.1080/00223890701845104

Examples


df <- data.frame(a = rnorm(100), b = rnorm(100), c = rnorm(100),
                 x = rnorm(100), y = rnorm(100), z = rnorm(100))
icc.de.mat(df)

Computation of the Double-Entry Intraclass Correlation between two profiles

Description

The function computes the double-entry intraclass correlation, which is an index of profile similarity (Furr, 2010; McCrae, 2008). The double-entry intraclass correlation is a more precise index of the agreement of two empirically observed profiles than the often-used intraclass correlation (McCrae, 2008). The function transforms profiles comprising correlations according to the Fisher z-transformation before the double-entry intraclass correlation is calculated. If the profiles comprise scores such as sum scores from various personality scales, it is recommended to standardize each individual score prior to computation of the double-entry intraclass correlation (McCrae, 2008). See Furr (2010) <doi:10.1080/00223890903379134> or McCrae (2008) <doi:10.1080/00223890701845104> for details.

Usage

icc.de(prof1,
       prof2,
       input = c("cor", "score"),
       use = "pairwise",
       digits = 2,
       plot = TRUE,
       legend = TRUE,
       pos.legend = "topleft",
       main = NA,
       name_prof1 = "prof1",
       name_prof2 = "prof2")

Arguments

prof1

Vector of components of the nomological network of the first variable (input = "cor") or vector of components of the first profile (input = "score").

prof2

Vector of components of the nomological network of the second variable (input = "cor") or vector of components of the second profile (input = "score").

input

Do the profiles contain correlations (e.g., from nomological network; input = "cor") or scores from different scales (e.g., sum scores from diverse personality tests; input = "score")? The default is input = "cor".

use

Optional character string specifying how to deal with missing values. The input will be forwarded to the base cor function and can be one of the following strings, including abbreviation: "everything", "all.obs", "complete.obs", "na.or.complete", or "pairwise.complete.obs". The default is use = "pairwise".

digits

Number of digits in the output. The default is digits = 2.

plot

Optional. Should the trajectories be visualized?

legend

Optional. Should a legend be added to the plot?

pos.legend

Optional. If legend = TRUE, the position of the legend can be specified. The edible default is pos.legend = "topleft". Alternative positions are "bottomright", "bottom", "bottomleft", "left", "top", "topright", "right", and "center".

main

Optional. Header/title of the optional plot.

name_prof1

Optional. Alternative name to be displayed in the output for prof1.

name_prof2

Optional. Alternative name to be displayed in the output for prof2.

Value

iccde

Double-Entry Intraclass Correlation for two given profiles

Mean_prof1, Mean_prof2

Means of the coefficients entered as prof1 and prof2, respectively.

SD_prof1, SD_prof2

Standard deviation of the coefficients entered as prof1 and prof2, respectively.

Author(s)

Christian Blötner, Michael Paul Grosz c.bloetner@gmail.com

References

Furr, R. M. (2010). The Double-Entry Intraclass Correlation as an Index of Profile Similarity: Meaning, Limitations, and Alternatives. Journal of Personality Assessment, 92(1), 1–15. https://doi.org/10.1080/00223890903379134

McCrae, R. R. (2008). A Note on Some Measures of Profile Agreement. Journal of Personality Assessment, 90(2), 105–109. https://doi.org/10.1080/00223890701845104

Examples

icc.de(prof1 = c(.59, .48, .23),
       prof2 = c(.52, .76, .22),
       input = "cor")

icc.de(prof1 = c(-1, -0.85, 2),
       prof2 = c(-0.93, 1, 1.26),
       input = "score",
       digits = 4)

Need mirroring services?
Contact our team at info@vpspulse.com.

Mirror powered by VPSpulse

Infrastructure sponsored by VPSPulse & Secure Payments by ArionPay.